==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/GridColumnAnimationSettingsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnAnimationSettingsDescription } from "./GridColumnAnimationSettingsDescription";
/**
 * @hidden
 */
var GridColumnAnimationSettingsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridColumnAnimationSettingsDescriptionMetadata, _super);
    function GridColumnAnimationSettingsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnAnimationSettingsDescriptionMetadata.b = function (a) {
        if (GridColumnAnimationSettingsDescriptionMetadata.a == null) {
            GridColumnAnimationSettingsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnAnimationSettingsDescriptionMetadata.c(GridColumnAnimationSettingsDescriptionMetadata.a);
        }
        if (a.g(GridColumnAnimationSettingsDescriptionMetadata.a)) {
            return;
        }
        a.s(GridColumnAnimationSettingsDescriptionMetadata.a);
    };
    GridColumnAnimationSettingsDescriptionMetadata.c = function (a) {
    };
    GridColumnAnimationSettingsDescriptionMetadata.d = function (a) {
        GridColumnAnimationSettingsDescriptionMetadata.b(a);
        a.u("GridColumnAnimationSettings", function () { return new GridColumnAnimationSettingsDescription(); });
        a.t("GridColumnAnimationSettings", GridColumnAnimationSettingsDescriptionMetadata.a);
    };
    GridColumnAnimationSettingsDescriptionMetadata.$t = markType(GridColumnAnimationSettingsDescriptionMetadata, 'GridColumnAnimationSettingsDescriptionMetadata');
    GridColumnAnimationSettingsDescriptionMetadata.a = null;
    return GridColumnAnimationSettingsDescriptionMetadata;
}(Base));
export { GridColumnAnimationSettingsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/GridColumnAnimationSettingsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnAnimationSettingsDescription } from "./GridColumnAnimationSettingsDescription";
/**
 * @hidden
 */
var GridColumnAnimationSettingsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(GridColumnAnimationSettingsDescriptionMetadata, _super);
    function GridColumnAnimationSettingsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    GridColumnAnimationSettingsDescriptionMetadata.b = function (a) {
        if (GridColumnAnimationSettingsDescriptionMetadata.a == null) {
            GridColumnAnimationSettingsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            GridColumnAnimationSettingsDescriptionMetadata.c(GridColumnAnimationSettingsDescriptionMetadata.a);
        }
        if (a.j(GridColumnAnimationSettingsDescriptionMetadata.a)) {
            return;
        }
        a.y(GridColumnAnimationSettingsDescriptionMetadata.a);
    };
    GridColumnAnimationSettingsDescriptionMetadata.c = function (a) {
    };
    GridColumnAnimationSettingsDescriptionMetadata.d = function (a) {
        GridColumnAnimationSettingsDescriptionMetadata.b(a);
        a.aa("GridColumnAnimationSettings", function () { return new GridColumnAnimationSettingsDescription(); });
        a.z("GridColumnAnimationSettings", GridColumnAnimationSettingsDescriptionMetadata.a);
    };
    GridColumnAnimationSettingsDescriptionMetadata.$t = markType(GridColumnAnimationSettingsDescriptionMetadata, 'GridColumnAnimationSettingsDescriptionMetadata');
    GridColumnAnimationSettingsDescriptionMetadata.a = null;
    return GridColumnAnimationSettingsDescriptionMetadata;
}(Base));
export { GridColumnAnimationSettingsDescriptionMetadata };
